LockedDownTraits
================

.. currentmodule:: wwt_data_formats

.. autoclass:: LockedDownTraits
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LockedDownTraits.rmeta

   .. rubric:: Attributes Documentation

   .. autoattribute:: rmeta
